==> TensorImage-2.0.1.tar.gz: TensorImage-2.0.1/README.md <==
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![Generic badge](https://img.shields.io/badge/docs-passing-green.svg)](https://shields.io/) 
[![GitHub release](https://img.shields.io/github/release/tensorimage/tensorimage.svg)](https://GitHub.com/tensorimage/tensorimage/releases/)
[![Github all releases](https://img.shields.io/github/downloads/tensorimage/tensorimage/total.svg)](https://GitHub.com/tensorimage/tensorimage/releases/)

## TensorImage
![Example](https://cdn-images-1.medium.com/max/1600/1*PAqzvCxPjpDN8RC9HQw45w.jpeg) 


__TensorImage__ is and open source image classification library designed to easily train and deploy models.

The main features are:
- Image classification model training. A wide range of data augmentation operations to boost testing accuracy and prevent overfitting are available

- Training clusters -- makes hyperparameter tuning easier and faster by automatically comparing performance of different models

- Organization -- all files, data and trained models are automatically stored and ordered inside your workspace directory which can be accessed at any time

- Large-scale deployment of trained image classification models -- generating more training data for further improved classification

### Installation
From the terminal:
```shell
$ pip3 install tensorimage
```

### Documentation
You can view TensorImage's documentation [here](https://tensorimage.readthedocs.io/en/latest/).

### Support
If you are experiencing any errors or bugs, please report them in the [issues section](https://github.com/TensorImage/TensorImage/issues) or contact us at tensor.image2@gmail.com

### Contributing
If you have any ideas for features that should be added to TensorImage, please feel free to [fork](https://github.com/TensorImage/tensorimage/network/members) TensorImage and [open a pull request](https://github.com/TensorImage/tensorimage/pulls).

### License
[MIT](https://github.com/TensorImage/tensorimage/blob/master/LICENSE.md)

==> TensorImage-2.0.2.tar.gz: TensorImage-2.0.2/README.md <==
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/20ce98b051b94e048fdb47452aa334c5)](https://app.codacy.com/app/TensorImage/tensorimage?utm_source=github.com&utm_medium=referral&utm_content=TensorImage/tensorimage&utm_campaign=Badge_Grade_Dashboard)
[![CodeFactor](https://www.codefactor.io/repository/github/tensorimage/tensorimage/badge)](https://www.codefactor.io/repository/github/tensorimage/tensorimage)
[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![GitHub release](https://img.shields.io/github/release/tensorimage/tensorimage.svg)](https://GitHub.com/tensorimage/tensorimage/releases/)

## TensorImage
![Example](https://cdn-images-1.medium.com/max/1600/1*PAqzvCxPjpDN8RC9HQw45w.jpeg) 


__TensorImage__ is an open source image classification library designed to easily train and deploy models.

The main features are:
- Image classification model training. A wide range of data augmentation operations to boost testing accuracy and prevent overfitting are available

- Training clusters -- makes hyperparameter tuning easier and faster by automatically comparing performance of different models

- Organization -- all files, data and trained models are automatically stored and ordered inside your workspace directory which can be accessed at any time

- Large-scale deployment of trained image classification models -- generating more training data for further improved classification

### Installation
From the terminal:
```shell
$ pip3 install tensorimage
```

### Documentation
You can view TensorImage's documentation [here](https://tensorimage.readthedocs.io/en/latest/).

### Support
If you are experiencing any errors or bugs, please report them in the [issues section](https://github.com/TensorImage/TensorImage/issues) or contact us at tensor.image2@gmail.com

### Contributing
If you have any ideas for features that should be added to TensorImage, please feel free to [fork](https://github.com/TensorImage/tensorimage/network/members) TensorImage and [open a pull request](https://github.com/TensorImage/tensorimage/pulls).

### License
[MIT](https://github.com/TensorImage/tensorimage/blob/master/LICENSE.md)
